import { addMaterialApi } from '@/services/task-api/task';
import { MaterialTypeEnum } from '@/utils/constEnum';
import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons';
import { useRequest } from 'ahooks';
import { Button, Form, message, Modal, Popconfirm, Space } from 'antd';
import React, { useMemo, useState } from 'react';
import Video from './video';

interface Props {
  taskId: number;
  name: string;
  materialType: MaterialTypeEnum;
  materialClaimJson: string;
  onChange?: () => void;
}
/**
 * 提交素材
 * @returns
 */
const SubmitTask: React.FC<Props> = ({
  taskId,
  name,
  materialType,
  materialClaimJson,
  onChange,
}) => {
  /*********************************/
  const [form] = Form.useForm<{ materialBeanList: TASKAPI.MaterialBean[] }>();
  const [visible, setVisible] = useState<boolean>(false);
  const addMaterial = useRequest(addMaterialApi, { manual: true });
  /*********************************/

  const hanldeOk = async () => {
    form.submit();
    let data = await form.validateFields();
    console.log(data);
    addMaterial.runAsync({ ...data, taskId, materialType }).then((res) => {
      if (res?.data) {
        message.success('提交成功');
        setVisible(false);
        form.resetFields();
        onChange?.();
      }
    });
  };

  const typeEle = useMemo(() => {
    switch (materialType) {
      // 视频提交
      case 'MATERIAL_TYPE_VIDEO' as MaterialTypeEnum:
        return <Video materialClaimJson={materialClaimJson} />;
      default:
        return null;
    }
  }, [materialType, materialClaimJson]);

  return (
    <>
      <Button
        type="primary"
        onClick={() => {
          setVisible(true);
        }}
      >
        提交素材
      </Button>
      {visible && (
        <Modal
          title={`提交${(MaterialTypeEnum as any)[materialType]}素材到 ${name}`}
          open={visible}
          onCancel={() => setVisible(false)}
          onOk={hanldeOk}
        >
          <Form
            name="submitTaskModal"
            form={form}
            initialValues={{
              materialBeanList: [
                {},
                // {
                //     md5: '9c7a0c1350f9d096b2fdfae1b38051f0',
                //     size: 10005155,
                //     url: "https://zx-material-center-test.oss-cn-hangzhou.aliyuncs.com/video/14A37EB1B19641CEB337DBBBC58A7B60.mp4"

                // }, {
                //     md5: "b18584adcedff777f2c35685390209af",
                //     size: 2300583,
                //     url: "https://zx-material-center-test.oss-cn-hangzhou.aliyuncs.com/video/1616F0AB21DE4F088D70A12FBB3F6C23.mp4"
                // }
              ],
            }}
          >
            <Form.List name="materialBeanList">
              {(fields, { add, remove }) => {
                return (
                  <>
                    {fields.map(({ key, name, ...restField }) => (
                      <Space key={key} style={{ display: 'flex', marginBottom: 8 }} align="center">
                        <Form.Item
                          {...restField}
                          name={[name]}
                          rules={[{ required: true, message: '请上传素材' }]}
                        >
                          {typeEle}
                        </Form.Item>
                        {fields?.length > 1 && (
                          <Popconfirm title="确定删除？" onConfirm={() => remove(name)}>
                            <MinusCircleOutlined style={{ color: 'red' }} />
                          </Popconfirm>
                        )}
                      </Space>
                    ))}
                    <Form.Item>
                      <Button type="dashed" onClick={() => add()} block icon={<PlusOutlined />}>
                        新增素材
                      </Button>
                    </Form.Item>
                  </>
                );
              }}
            </Form.List>
          </Form>
        </Modal>
      )}
    </>
  );
};

export default React.memo(SubmitTask);
